.. _plasmapy-particles:

********************************
Particles (`plasmapy.particles`)
********************************

.. py:module:: plasmapy.particles
.. currentmodule:: plasmapy.particles

Introduction
============

The `~plasmapy.particles` subpackage provides access to information
about atoms, ions, isotopes, and other particles. |:atom:|

Submodules
==========

.. toctree::
   :maxdepth: 2

   particle_class
   functional
   nuclear
   ionization_states
   decorators

Examples
========

.. nbgallery::

    /notebooks/getting_started/particles

See Also
========

- The `mendeleev <https://pypi.org/project/mendeleev/>`_ Python
  package provides access to properties of elements, isotopes, and ions
  in the periodic table of elements.

API
===

.. automodapi:: plasmapy.particles
   :noindex:
   :no-main-docstring:
